@@ -41,13 +41,13 @@ class QFile;
 class ClipBoard;
 class KUrl;
 class MultiTrackReader;
-class MultiTrackWriter;
 class SampleReader;
 class SignalWidget;
 class Track;
 class UndoAction;
 class UndoTransaction;
 class UndoTransactionGuard;
+namespace Kwave { class Writer; }
 
 #define NEW_FILENAME i18n("New File")
 
@@ -190,6 +190,17 @@ public:
      */
     bool deleteRange(unsigned int offset, unsigned int length);
 
+    /**
+     * Inserts space at a given position and creates an undo action.
+     * @param offset position of the first sample to insert
+     * @param length number of samples
+     * @param track_list a list of tracks to be affected
+     * @return true if successful or nothing to do, false if not enough
+     *         memory for undo
+     */
+    bool insertSpace(unsigned int offset, unsigned int length,
+                     const QList<unsigned int> &track_list);
+
     /**
      * Sets the current start and length of the selection to new values.
      * @param offset index of the first sample
@@ -243,7 +254,7 @@ public:
      * @param with_undo if true, an undo action will be created
      * @see InsertMode
      */
-    SampleWriter *openSampleWriter(unsigned int track, InsertMode mode,
+    Kwave::Writer *openWriter(unsigned int track, InsertMode mode,
 	unsigned int left = 0, unsigned int right = 0,
 	bool with_undo = false);
 
