@@ -71,6 +71,9 @@ public:
      */
     virtual UndoAction *undo(SignalManager &manager, bool with_redo);
 
+    /** dump, for debugging purposes */
+    virtual void dump(const QString &indent);
+
 private:
 
     /** parent widget for showing error messages */
