@@ -29,6 +29,17 @@ UndoSelection::UndoSelection(SignalManager &manager)
 {
 }
 
+//***************************************************************************
+UndoSelection::UndoSelection(SignalManager &manager,
+                             QList<unsigned int> selected_tracks,
+                             unsigned int offset,
+                             unsigned int length)
+    :UndoAction(),
+     m_manager(manager), m_offset(offset), m_length(length),
+     m_selected_tracks(selected_tracks)
+{
+}
+
 //***************************************************************************
 UndoSelection::~UndoSelection()
 {
@@ -87,5 +98,14 @@ UndoAction *UndoSelection::undo(SignalManager &manager, bool with_redo)
     }
 }
 
+//***************************************************************************
+void UndoSelection::dump(const QString &indent)
+{
+    qDebug("%sselect from [%u ... %u] (%d)", indent.toLocal8Bit().data(),
+           m_offset,
+           m_offset + ((m_length) ? (m_length - 1) : m_length),
+           m_length);
+}
+
 //***************************************************************************
 //***************************************************************************
