@@ -41,6 +41,18 @@ public:
      */
     UndoSelection(SignalManager &manager);
 
+    /**
+     * Constructor.
+     * @param manager reference to the SignalManager
+     * @param selected_tracks list of selected tracks
+     * @param offset start of the selection
+     * @param length number of selected samples
+     */
+    UndoSelection(SignalManager &manager,
+                  QList<unsigned int> selected_tracks,
+                  unsigned int offset,
+                  unsigned int length);
+
     /** virtual destructor */
     virtual ~UndoSelection();
 
@@ -62,6 +74,9 @@ public:
     /** @see UndoAction::containsModification() */
     virtual bool containsModification() const { return false; }
 
+    /** dump, for debugging purposes */
+    virtual void dump(const QString &indent);
+
 private:
 
     /** reference to the SignalManager is needed in redoSize() */
