@@ -26,10 +26,10 @@
 #include "libkwave/GenreType.h"
 #include "libkwave/KwaveSampleArray.h"
 #include "libkwave/MessageBox.h"
-#include "libkwave/MultiTrackWriter.h"
+#include "libkwave/MultiWriter.h"
 #include "libkwave/Sample.h"
-#include "libkwave/SampleWriter.h"
 #include "libkwave/Signal.h"
+#include "libkwave/Writer.h"
 
 #include "MP3Decoder.h"
 #include "ID3_QIODeviceReader.h"
@@ -392,7 +392,10 @@ bool MP3Decoder::open(QWidget *widget, QIODevice &src)
     tag.Link(adapter, static_cast<flags_t>(ID3TT_ALL));
 
     qDebug("NumFrames = %d", static_cast<int>(tag.NumFrames()));
-    qDebug("Size = %d",      static_cast<int>(tag.Size()));
+    /** @bug: id3lib crashes in this line on some MP3 files */
+    if (tag.GetSpec() != ID3V2_UNKNOWN) {
+	qDebug("Size = %d",      static_cast<int>(tag.Size()));
+    }
     qDebug("HasLyrics = %d", tag.HasLyrics());
     qDebug("HasV1Tag = %d",  tag.HasV1Tag());
     qDebug("HasV2Tag = %d",  tag.HasV2Tag());
@@ -655,7 +658,7 @@ enum mad_flow MP3Decoder::processOutput(void */*data*/,
 }
 
 //***************************************************************************
-bool MP3Decoder::decode(QWidget *widget, MultiTrackWriter &dst)
+bool MP3Decoder::decode(QWidget *widget, Kwave::MultiWriter &dst)
 {
     Q_ASSERT(m_source);
     if (!m_source) return false;
