@@ -41,7 +41,6 @@
 #include "libkwave/Matrix.h"
 #include "libkwave/MessageBox.h"
 #include "libkwave/MultiTrackReader.h"
-#include "libkwave/MultiTrackWriter.h"
 #include "libkwave/PlaybackController.h"
 #include "libkwave/PlayBackDevice.h"
 #include "libkwave/PluginManager.h"
@@ -57,6 +56,7 @@
 #include "PlayBack-OSS.h"
 #include "PlayBack-ALSA.h"
 #include "PlayBack-Phonon.h"
+#include "PlayBack-PulseAudio.h"
 
 #include "PlayBackDialog.h"
 #include "PlayBackPlugin.h"
@@ -268,6 +268,11 @@ PlayBackDevice *PlayBackPlugin::createDevice(playback_method_t &method)
 		return new PlayBackPhonon();
 #endif /* HAVE_PHONON_SUPPORT */
 
+#ifdef HAVE_PULSEAUDIO_SUPPORT
+	    case PLAYBACK_PULSEAUDIO:
+		return new PlayBackPulseAudio(fileInfo());
+#endif /* HAVE_PULSEAUDIO_SUPPORT */
+
 	    default:
 		qDebug("unsupported playback method (%d)",
 		    static_cast<int>(method));
@@ -335,7 +340,8 @@ void PlayBackPlugin::setMethod(playback_method_t method)
 		device.toLocal8Bit().data());
 	    last_device_name = device;
 	    m_playback_params.device = device;
-	    m_dialog->setDevice(m_playback_params.device);
+	    m_dialog->setSupportedDevices(QList<QString>());
+ 	    m_dialog->setDevice(m_playback_params.device);
 	}
     }
     Q_ASSERT(m_device);
@@ -380,6 +386,9 @@ void PlayBackPlugin::setDevice(const QString &device)
     QString dev = device;
     if (m_device) {
 	QStringList supported = m_device->supportedDevices();
+	supported.removeAll("#EDIT#");
+	supported.removeAll("#SELECT#");
+	supported.removeAll("#TREE#");
 	if (!supported.isEmpty() && !supported.contains(device)) {
 	    // use the first entry as default
 	    dev = supported.first();
@@ -505,7 +514,7 @@ void PlayBackPlugin::startDevicePlayBack()
 
     unsigned int first;
     unsigned int last;
-    selection(&first, &last, false);
+    selection(0, &first, &last, false);
 
     if (m_playback_controller.paused()) {
 	// continue after pause
@@ -527,7 +536,6 @@ void PlayBackPlugin::startDevicePlayBack()
 		// nothing selected -> select all and move to position
 		m_playback_controller.setStartPos(first);
 		m_playback_controller.setEndPos(signalLength()-1);
-		m_playback_controller.updatePlaybackPos(first);
 	    }
 	}
     } else {
@@ -548,7 +556,6 @@ void PlayBackPlugin::startDevicePlayBack()
     m_old_last = last;
 
     QStringList empty_list;
-    use();
     execute(empty_list);
 }
 
@@ -575,8 +582,8 @@ void PlayBackPlugin::run(QStringList)
     // get the list of selected channels
     QList<unsigned int> audible_tracks = selectedTracks();
     unsigned int audible_count = audible_tracks.count();
-    if (!audible_count) {
-	// not even one selected track
+    if (!audible_count || !m_device) {
+	// not even one selected track or no (open) device
 	qDebug("PlayBackPlugin::run(): no audible track(s) !");
 	emit sigPlaybackDone();
 	return;
